@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -116,6 +88,13 @@ public interface GuardDatabaseService {
      */
     void backWritableForGuardNoTimeout(Connection connection);
 
+    /**
+     * Returns a writable connection without timeout to the ox guard database that was only used for reading
+     *
+     * @param connection Writable connection to return.
+     */
+    void backWritableAfterReadingForGuardNoTimeout(Connection connection);
+
     /**
      * Returns a writable connection to the shard database.
      *
@@ -133,6 +112,20 @@ public interface GuardDatabaseService {
      */
     Connection getWritableForShardNoTimeout(int shardId) throws OXException;
 
+    /**
+     * Returns a writable connection without timeout to the shard database.
+     *
+     * @param connection Writable connection to return.
+     */
+    void backWritableForShardNoTimeout(int shardId, Connection connection);
+
+    /**
+     * Returns a writable connection without timeout to the shard database that was only used for reading
+     *
+     * @param connection Writable connection to return.
+     */
+    void backWritableAfterReadingForShardNoTimeout(int shardId, Connection connection);
+
     /**
      * Returns a read only connection to the shard database.
      *
@@ -158,13 +151,6 @@ public interface GuardDatabaseService {
      */
     void backWritableForShard(int shardId, Connection connection);
 
-    /**
-     * Returns a writable connection without timeout to the shard database.
-     *
-     * @param connection Writable connection to return.
-     */
-    void backWritableForShardNoTimeout(int shardId, Connection connection);
-
     /**
      * Returns a {@link GuardConnectionWrapper} containing a writable connection to the database the user is associated to.
      *
