@@ -7,9 +7,12 @@ import com.openexchange.guard.database.GuardShardingService;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.guestupgrade.GuestUpgradeService;
 import com.openexchange.guard.guestupgrade.internal.GuestUpgradeServiceImpl;
+import com.openexchange.guard.guestupgrade.storage.GuestUpgradeStorageService;
+import com.openexchange.guard.guestupgrade.storage.GuestUpgradeStorageServiceImpl;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
+import com.openexchange.guard.user.OXUserService;
 import com.openexchange.osgi.HousekeepingActivator;
 
 /**
@@ -24,7 +27,7 @@ public class GuestUpgradeServiceActivator extends HousekeepingActivator {
     protected Class<?>[] getNeededServices() {
         return new Class<?>[]{GuardKeyService.class, KeyTableStorage.class,
                               EmailStorage.class, PGPKeysStorage.class,
-                              GuardDatabaseService.class, GuardShardingService.class };
+                              GuardDatabaseService.class, GuardShardingService.class, OXUserService.class};
     }
 
     @Override
@@ -33,6 +36,9 @@ public class GuestUpgradeServiceActivator extends HousekeepingActivator {
         logger.info("Starting bundle {}", context.getBundle().getSymbolicName());
         Services.setServiceLookup(this);
         registerService(GuestUpgradeService.class, new GuestUpgradeServiceImpl());
+        registerService(GuestUpgradeStorageService.class, new GuestUpgradeStorageServiceImpl(getService(GuardDatabaseService.class)));
+        trackService(GuestUpgradeStorageService.class);
+        openTrackers();
         logger.info("GuardGuestUpgrade registered.");
     }
 
