@@ -89,7 +89,7 @@ public class CachingHKPClientService implements HKPClientService {
      * @return A list for key rings found for the given email
      * @throws Exception
      */
-    private Collection<RemoteKeyResult> findAllInternal(String clientToken, String email, int timeout) throws Exception {
+    private Collection<RemoteKeyResult> findAllInternal(String clientToken, String email, int userId, int cid, int timeout) throws Exception {
 
         //Searching keys in the cache
         Collection<CachedKey> ret = null;
@@ -106,12 +106,12 @@ public class CachingHKPClientService implements HKPClientService {
         Collection<RemoteKeyResult> result = null;
         //Search delegate
         if (delegate != null) {
-            result = delegate.find(clientToken, email, timeout);
+            result = delegate.find(clientToken, email, userId, cid, timeout);
         }
 
         if (result != null && !result.isEmpty()) {
             //Only save from trusted sources
-            Collection<RemoteKeyResult> trustedResults = RemoteKeyResult.getTrusted(result);
+            Collection<RemoteKeyResult> trustedResults = RemoteKeyResult.getTrusted(result, userId, cid);
             if(trustedResults != null && trustedResults.size() > 0) {
                 logger.debug("Writing {} found keys from trusted HKP server into cache", trustedResults.size());
                 writeToCache(trustedResults.toArray(new RemoteKeyResult[trustedResults.size()]));
@@ -126,10 +126,13 @@ public class CachingHKPClientService implements HKPClientService {
      * @param clientToken
      * @param id
      * @param email
+     * @param userId ID of the sender
+     * @param cid Context of the sender
+     * @param timeout Time remaining for lookup
      * @return
      * @throws Exception
      */
-    private RemoteKeyResult findInternal(String clientToken, Long id, String email, int timeout) throws Exception {
+    private RemoteKeyResult findInternal(String clientToken, Long id, String email, int userId, int cid, int timeout) throws Exception {
 
         CachedKey cachedKey = findInCache(id);
         if (cachedKey != null) {
@@ -139,11 +142,11 @@ public class CachingHKPClientService implements HKPClientService {
         RemoteKeyResult result = null;
         //Search delegate
         if (delegate != null) {
-            result = delegate.find(clientToken, email, id, timeout);
+            result = delegate.find(clientToken, email, id, userId, cid, timeout);
         }
 
         if (result != null && result.hasResult()) {
-            if (result.getSource().isTrusted()) { // Only save from trusted sources
+            if (result.getSource().isTrusted(userId, cid)) { // Only save from trusted sources
                 logger.debug("Writing found keys from HKP server into cache");
                 writeToCache(result);
             }
@@ -152,18 +155,18 @@ public class CachingHKPClientService implements HKPClientService {
     }
 
     @Override
-    public Collection<RemoteKeyResult> find(String clientToken, String email, int timeout) throws OXException {
+    public Collection<RemoteKeyResult> find(String clientToken, String email, int userId, int cid, int timeout) throws OXException {
         try {
-            return findAllInternal(clientToken, email, timeout);
+            return findAllInternal(clientToken, email, userId, cid, timeout);
         } catch (Exception e) {
             throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
     }
 
     @Override
-    public RemoteKeyResult find(String clientToken, String email, Long id, int timeout) throws OXException {
+    public RemoteKeyResult find(String clientToken, String email, Long id, int userId, int cid, int timeout) throws OXException {
         try {
-            return findInternal(clientToken, id, email, timeout);
+            return findInternal(clientToken, id, email, userId, cid, timeout);
         } catch (Exception e) {
             throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
