@@ -27,5 +27,8 @@ public final class GuardKeysExceptionCodes implements LocalizableStrings {
     // Current password is required to change the password
     public static final String PREVIOUSLY_CHANGED = "Current password required for password change.";
 
+    // Unable to revoke the keys due to the following reason.
+    public static final String REVOKE_FAILED = "Unable to revoke keys. %1$s";
+
 
 }
