@@ -52,4 +52,11 @@ public interface PasswordChangeService {
      * @throws OXException
      */
     GuardKeys changeTemporaryPassword (int userid, int cid, String password) throws OXException;
+
+    /**
+     * Check newpassword against password requirements
+     * @param newpass
+     * @throws OXException
+     */
+    void checkPasswordRequirements(String newpass) throws OXException;
 }
