@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -81,6 +53,8 @@ import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.guard.pgpcore.services.PGPMimeCryptoService;
 import com.openexchange.guard.pgpcore.services.PGPSigningService;
+import com.openexchange.guard.user.GuardCapabilities;
+import com.openexchange.guard.user.OXUserService;
 import com.openexchange.guard.user.UserIdentity;
 import com.openexchange.pgp.mail.PGPMimeService;
 
@@ -166,6 +140,23 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
         }
     }
 
+    /**
+     * Check if user has Guard-mail capability. Throw error if not
+     * checkGuardMailCapable
+     *
+     * @param userId
+     * @param contextId
+     * @throws OXException Thrown if user doesn't have guard-mail
+     */
+    private void checkGuardMailCapable(int userId, int contextId) throws OXException {
+        OXUserService userService = Services.getService(OXUserService.class);
+        if (userService != null) {
+            GuardCapabilities cap = userService.getGuardCapabilieties(contextId, userId);
+            if (!cap.hasPermission(GuardCapabilities.Permissions.MAIL)) {
+                throw MimeEncryptorExceptionCodes.SEND_NOT_AUTHORIZED.create();
+            }
+        }
+    }
     /**
      * Send email for signing only.  Not encypted
      * @param response
@@ -177,6 +168,7 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
      */
     private void doSigning (OutputStream output, int userId, int contextId, String password, GuardParsedMimeMessage msg) throws Exception {
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
+        checkGuardMailCapable(userId, contextId);  // Make sure has guard-mail capability to send signed emails
         GuardKeys key = keyService.getKeys(userId, contextId);
         if (key == null) {
             throw MimeEncryptorExceptionCodes.SEND_UNABLE_FIND_KEYS.create("Unable to find singing keys");
