@@ -11,9 +11,9 @@ import com.openexchange.exception.OXException;
 import com.openexchange.guard.email.storage.ogEmail.Email;
 import com.openexchange.guard.guest.GuestLookupService;
 import com.openexchange.guard.osgi.Services;
+import com.openexchange.guard.oxapi.SessionInformation;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.OxCookie;
-import com.openexchange.guard.oxapi.SessionInformation;
 
 /**
  * {@link RestSessionValidator} Validates the sessionID using the OX Rest API
@@ -88,9 +88,8 @@ public class RestSessionValidator implements SessionValidator {
                 else {
                     logger.debug("Unable to obtain session information for session {}", sessionId);
                 }
-            }
-            else {
-               logger.debug("Unable to verify session {0}", sessionId);
+            } else {
+                logger.error("Unable to verify session {0}", sessionId);
             }
         }
         return null;
